@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2003, 2004, 2005, 2006 Joe Walnes.
- * Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011 XStream Committers.
+ * Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013 XStream Committers.
  * All rights reserved.
  *
  * The software in this package is published under the terms of the BSD
@@ -592,8 +592,8 @@ public class XStream {
             // Instantiating these two classes starts the AWT system, which is undesirable.
             // Calling loadClass ensures a reference to the class is found but they are not
             // instantiated.
-            alias("awt-color", jvm.loadClass("java.awt.Color"));
-            alias("awt-font", jvm.loadClass("java.awt.Font"));
+            alias("awt-color", jvm.loadClass("java.awt.Color", false));
+            alias("awt-font", jvm.loadClass("java.awt.Font", false));
             alias("awt-text-attribute", jvm.loadClass("java.awt.font.TextAttribute"));
         }
 
@@ -618,6 +618,7 @@ public class XStream {
 
         if (JVM.is15()) {
             aliasDynamically("duration", "javax.xml.datatype.Duration");
+            alias("concurrent-hash-map", jvm.loadClass("java.util.concurrent.ConcurrentHashMap"));
             alias("enum-set", jvm.loadClass("java.util.EnumSet"));
             alias("enum-map", jvm.loadClass("java.util.EnumMap"));
             alias("string-builder", jvm.loadClass("java.lang.StringBuilder"));
@@ -931,7 +932,7 @@ public class XStream {
      * @since 1.4
      */
     public Object fromXML(URL url) {
-        return unmarshal(hierarchicalStreamDriver.createReader(url), null);
+        return fromXML(url, null);
     }
 
     /**
@@ -944,7 +945,7 @@ public class XStream {
      * @since 1.4
      */
     public Object fromXML(File file) {
-        return unmarshal(hierarchicalStreamDriver.createReader(file), null);
+        return fromXML(file, null);
     }
 
     /**
@@ -1000,7 +1001,12 @@ public class XStream {
      * @since 1.4
      */
     public Object fromXML(File file, Object root) {
-        return unmarshal(hierarchicalStreamDriver.createReader(file), root);
+        HierarchicalStreamReader reader = hierarchicalStreamDriver.createReader(file);
+        try {
+            return unmarshal(reader, root);
+        } finally {
+            reader.close();
+        }
     }
 
     /**
@@ -1485,7 +1491,7 @@ public class XStream {
      *            map type or matching the default implementation type of the map
      *            type.
      * @param itemType type of the items to be part of this map as value
-     * @param keyFieldName the name of the filed of the itemType that is used for the key in the map
+     * @param keyFieldName the name of the field of the itemType that is used for the key in the map
      * @since 1.4 
      */
     public void addImplicitMap(Class ownerType, String fieldName, Class itemType, String keyFieldName) {
@@ -1499,18 +1505,19 @@ public class XStream {
      * @param fieldName name of the field in the ownerType. This field must be a concrete
      *            map type or matching the default implementation type of the map
      *            type.
+     * @param itemName alias name of the items
      * @param itemType type of the items to be part of this map as value
-     * @param keyFieldName the name of the filed of the itemType that is used for the key in the map
+     * @param keyFieldName the name of the field of the itemType that is used for the key in the map
      * @since 1.4 
      */
-    public void addImplicitMap(Class ownerType, String fieldName, String itemFieldName, 
+    public void addImplicitMap(Class ownerType, String fieldName, String itemName, 
         Class itemType, String keyFieldName) {
         if (implicitCollectionMapper == null) {
             throw new com.thoughtworks.xstream.InitializationException("No "
                 + ImplicitCollectionMapper.class.getName()
                 + " available");
         }
-        implicitCollectionMapper.add(ownerType, fieldName, itemFieldName, itemType, keyFieldName);
+        implicitCollectionMapper.add(ownerType, fieldName, itemName, itemType, keyFieldName);
     }
 
     /**
